@@ -1,7 +1,30 @@
+use crate::{Cache, Repository};
+
+mod access {
+    use crate::{Kind, Repository};
+
+    impl Repository {
+        pub fn kind(&self) -> Kind {
+            match self.working_tree {
+                Some(_) => Kind::WorkingTree,
+                None => Kind::Bare,
+            }
+        }
+
+        pub fn git_dir(&self) -> &std::path::Path {
+            &self.refs.base
+        }
+        pub fn objects_dir(&self) -> &std::path::Path {
+            &self.odb.dbs[0].loose.path
+        }
+    }
+}
+
 mod init {
-    use crate::Repository;
     use std::path::Path;
 
+    use crate::Repository;
+
     impl Repository {
         /// Really just a sketch at this point to help guide the API.
         pub fn create_and_init(directory: impl AsRef<Path>) -> Result<Self, crate::init::Error> {
@@ -13,9 +36,11 @@ mod init {
 }
 
 pub mod discover {
-    use crate::{path::discover, Repository};
+    use std::{cell::RefCell, path::Path};
+
     use quick_error::quick_error;
-    use std::path::Path;
+
+    use crate::{path::discover, Repository};
 
     quick_error! {
         #[derive(Debug)]
